==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Test/Gui/Resources/translations/Test_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Avarie ed errori</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descrizione</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Inizio</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+I</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Aiuto</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Informazioni su</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+I</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Chiudi</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inattivo</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Avanzamento</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Rimanente:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Errori:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Avarie:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Serie:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Seleziona il nome del test:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Aiuto</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Informazioni su FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest è parte di FreeCAD e supporta la scrittura di test unitari per i propri moduli.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Inserisci il nome di un oggetto richiamabile che, quando richiamato, restituirà un TestCase. Fare clic su 'inizio', e la prova così prodotta sarà eseguita.

Doppio click su un errore nell'albero per visualizzare più informazioni, inclusa la traccia dello stack.</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Test/Gui/Resources/translations/Test_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Avarie ed errori</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descrizione</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Inizio</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+I</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Aiuto</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Informazioni su</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+I</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Chiudi</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inattivo</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Avanzamento</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Rimanente:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Errori:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Avarie:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Serie:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Seleziona il nome del test:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Aiuto</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Informazioni su FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest è parte di FreeCAD e supporta la scrittura di test unitari per i propri moduli.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Inserisci il nome di un oggetto richiamabile che, quando richiamato, restituirà un TestCase. Fare clic su 'inizio' e la prova così prodotta sarà eseguita.

Doppio clic su un errore nell'albero per visualizzare più informazioni, inclusa la traccia dello stack.</translation>
    </message>
  </context>
</TS>
